@@ -4,7 +4,8 @@ from urllib.parse import urlparse, urlunparse
 def normalize_git_url(url: str) -> str:
     """Normalize a git URL to https://, remove .git from the end of the path, and lowercase the hostname.
 
-    If the URL is malformed, return the original URL."""
+    If the URL is malformed, return the original URL.
+    """
     # Ignore local paths
     if "://" not in url:
         return url
@@ -18,10 +19,7 @@ def normalize_git_url(url: str) -> str:
         scheme = "https"
 
     # Lowercase the hostname and remove default port if it exists
-    if parsed_url.hostname:
-        netloc = parsed_url.hostname.lower()
-    else:
-        netloc = ""
+    netloc = parsed_url.hostname.lower() if parsed_url.hostname else ""
 
     # If netloc is empty (git, ssh URLs), then path contains it.
     if not netloc:
